import QtQuick 1.1
import qb.components 1.0

/**
	Component showing program blocks for single day together with tab-button for the day.
 */
Item {
	id: root

	property string kpiPostfix: "Thermostatday" + index
	property bool isDaySelected: false
	property bool dayEnabled: true

	// Signal emitted when day is daySelected
	// parameter dayToSelect is Sunday based index of the day
	signal daySelected(int dayToSelect);

	QtObject {
		id: p
		property int dayProgramHeight: 0

		function isLastInDay(blockIdx) {
			return (blockIdx === programModel.count - 1);
		}

		function isFirstInDay(blockIdx) {
			var result = (blockIdx === 0) || (blockIdx === 1 && (programModel.get(blockIdx).startHour + programModel.get(blockIdx).startMin === 0))
			return result;
		}

		function calculatePxHeight() {
			if (!programModel.count) return;
			var totalHeight = 0;
			var blockHeight = 0;
			var blockLength = 0;

			if (programModel.count === 1) {
				programModel.get(0).pxHeight = 220;
				return;
			}
			for (var i = 0; i < programModel.count - 1; i++) {
				blockLength = programModel.get(i + 1).startHour * 60 + programModel.get(i + 1).startMin;
				if (i > 0)
					blockLength -= programModel.get(i).startHour * 60 + programModel.get(i).startMin;
				//1.5 pixels per 10 minutes
				blockHeight = Math.floor(blockLength / 10 * 1.5);
				totalHeight += blockHeight;
				programModel.get(i).pxHeight = blockHeight;
			}
			//Last block in day
			programModel.get(programModel.count - 1).pxHeight = 220 - totalHeight;
		}
	}

	// Populate program for one day.
	function populateDayProgram(dayProgram) {
		programModel.clear();
		for(var i = 0; i < dayProgram.length; i++) {
			var programItem = dayProgram[i];
			programItem['pxHeight'] = 0;
			programModel.append(dayProgram[i]);
		}
		p.calculatePxHeight();
	}

	width: 75; height: 264;

	Component {
		id: programRectangle
		Item {
			width: 75; height: pxHeight;
			RoundedRectangle {
				id: rectangle
				shadowPixelSize: 0
				radius: 6
				mouseEnabled: false
				color: app.thermStateColor[targetState]
				height: parent.height - (p.isLastInDay(index) ? 0 : 2 )
				width: parent.width
				topLeftRadiusRatio: p.isFirstInDay(index) ? 1 : 0
				topRightRadiusRatio: p.isFirstInDay(index) ? 1 : 0
				bottomRightRadiusRatio: p.isLastInDay(index) ?  1 : 0
				bottomLeftRadiusRatio: p.isLastInDay(index) ? 1 : 0
				opacity: !dayEnabled ? 0.3 : (!isDaySelected ? 0.7 : 1)
				visible: height > 0

				Text {
					id: txtMode
					text: app.thermStateName[targetState]
					visible: (paintedHeight < parent.height) && isDaySelected && dayEnabled ? true : false
					color: colors.psModeName
					font.pixelSize: 15
					font.family: qfont.regular.name
					anchors.centerIn: parent
				}
			}
			Item {
				id: separator
				width: parent.width
				height: p.isLastInDay(index) ? 0 : 2
				anchors.bottom: parent.bottom
			}
		}
	}

	ListModel {
		id: programModel
	}

	RoundedRectangle {
		height: 220; width: parent.width
		color: colors.psDisabled
		opacity: 0.3
		anchors.top: parent.top
		anchors.topMargin: 44
		visible: !dayEnabled
	}


	Column {
		id: column
		height: 264; width: parent.width

		Item {
			id: dayButton
			width: parent.width; height: 44
			RoundedRectangle {
				id: txtDay
				height: 36; width: parent.width
				color: colors.psDayBckgUnselected
				opacity: (isDaySelected && dayEnabled) ? 0.8 : 1
				shadowPixelSize: (isDaySelected || !dayEnabled) ? 0 : 1
				Text {
					text: i18n.daysExtraShort[index + 1] // Monday based index
					color: { if (!dayEnabled) colors.psDisabled;
						else (isDaySelected && dayEnabled) ? colors.psDayTextSelected : colors.psDayTextUnselected }
					anchors.centerIn: parent
					font {
						family: qfont.semiBold.name
						pixelSize: 20
					}
				}
			}
		}

		Repeater {
			id: repeatProgram
			model: programModel
			delegate: programRectangle
			anchors.topMargin: 8;
		}
	}

	MouseArea {
		id: maColumn
		anchors.fill: column
		enabled: dayEnabled
		onClicked: {
			daySelected(app.mondayBaseToSundayBase(index));
		}
	}
}
