import QtQuick 1.1
import qb.components 1.0
import "../../themes"

/// Screen for setting vacation details.

Screen {
	id: vacationSetScreen
	screenTitle: qsTr("Vacation set")
	isSaveCancelDialog: true

	onSaved: {
		modeVacation.temperatureChanged();
		app.updateVacationData(app.tmpVacationData);
	}

	onShown: {
		if (args && args.newVacation) {
			var newVacationData = app.vacationData;
			var now = new Date();
			now.setMinutes(0, 0, 0);

			var vacationData = app.vacationData;
			newVacationData.startTime = now.getTime();
			btnStartDate.text = app.formatDateTime(now.getTime(), true);

			var future = new Date(now);
			future.setFullYear(future.getFullYear() + 5);
			newVacationData.endTime = future.getTime();
			btnEndDate.text = app.formatDateTime(future.getTime(), false);

			modeVacation.temperature = 6.0; // default vacation temperature
			app.tmpVacationData = newVacationData;
		} else {
			if (args && args.editVacation)
				app.tmpVacationData = app.vacationData;

			modeVacation.temperature = app.tmpVacationData.temperature;
			btnStartDate.text = app.formatDateTime(app.tmpVacationData['startTime'], true);
			btnEndDate.text = app.formatDateTime(app.tmpVacationData['endTime'], false);
		}
	}

	Item {
		id: txtBaseline
		width: parent.width; height: 104
		anchors {
			top: parent.top
			left: parent.left
			right: parent.right
		}
	}

	TemperatureModeSet {
		id: modeVacation
		label: qsTr("Temperature")
		color: colors.tpModeVacation
		textColorGap: 8
		temperature: 6
		anchors {
			left: parent.left
			leftMargin: 84
		}
		onTemperatureChanged: {
			var vacData = app.tmpVacationData;
			vacData.temperature = temperature;
			app.tmpVacationData = vacData;
		}
	}

	Text {
		id: txtStartDate
		text: qsTr("Start date")
		anchors {
			left: modeVacation.right
			leftMargin: 84
			baseline: parent.top
			baselineOffset: 104
		}
		font {
			family: qfont.semiBold.name
			pixelSize: 20
		}
		color: colors.tpModeLabel
	}

	RichTextButton {
		id: btnStartDate
		text: qsTr("Now")
		width: 165; height: 116
		anchors {
			left: txtStartDate.left
			top: txtStartDate.baseline
			topMargin: 8
		}
		kpiPostfix: "startDate"
		fontFamily: "Open Sans Regular"
		fontPixelSize: 18
		onClicked: {
			// set the minimum start time to now at most recent full hour
			var minDt = new Date();
			minDt.setMinutes(0, 0, 0);

			// set the initial value to the starting time of the vacation
			var init = new Date(app.tmpVacationData['startTime']);

			// set the maximum start time to the minimum plus two years
			var maxDt = new Date(minDt);
			maxDt.setFullYear(maxDt.getFullYear() + 2);

			// if vacation already has an end and it is before the start maximum,
			// set the start maximum to the end minus 1 hour
			if (app.tmpVacationData['endTime'] < maxDt.getTime()) {
				maxDt.setTime(app.tmpVacationData['endTime']);
				maxDt.setHours(maxDt.getHours() - 1);
			}

			stage.openFullscreen(app.vacationDateScreenUrl, {dateToChange: "startTime", initDt: init, minDt: minDt, maxDt: maxDt});
		}
	}

	Text {
		id: txtEndDate
		text: qsTr("End date")
		anchors {
			left: btnStartDate.right
			leftMargin: 54
			baseline: parent.top
			baselineOffset: 104
		}
		font {
			family: qfont.semiBold.name
			pixelSize: 20
		}
		color: colors.tpModeLabel
	}

	RichTextButton {
		id: btnEndDate
		width: 165; height: 116
		text: qsTr("Until I return")
		anchors {
			left: txtEndDate.left
			top: btnStartDate.top
		}
		kpiPostfix: "endDate"
		fontFamily: "Open Sans Regular"
		fontPixelSize: 18
		onClicked: {
			var now = new Date();
			// initialy set the end time to the start time's next full hour
			var init = new Date(app.tmpVacationData['startTime']);
			init.setHours(init.getHours() + 1);

			// if initial end time is in the past (because we are editing)
			// a previously created vacation, set initial end time to next full hour
			if (init.getTime() < now.getTime()) {
				init = now;
				init.setMinutes(0, 0, 0);
				init.setHours(init.getHours() + 1);
			}

			// minimum end time is also the initial date and time
			var minDt = new Date(init);
			// maximum end time is minimum plus two years
			var maxDt = new Date(minDt);
			maxDt.setFullYear(maxDt.getFullYear() + 2);

			// if vacation already has an end time and its smaller than
			// calculated maximum end time, set the initial end time to that
			if (app.tmpVacationData['endTime'] < maxDt.getTime()) {
				init.setTime(app.tmpVacationData['endTime']);
			}

			stage.openFullscreen(app.vacationDateScreenUrl, {dateToChange: "endTime", initDt: init, minDt: minDt, maxDt: maxDt});
		}
	}

	Text {
		id: txtTo
		text: qsTr("to")
		horizontalAlignment: Text.AlignHCenter
		verticalAlignment: Text.AlignVCenter

		font {
			family: qfont.regular.name
			pixelSize: 18
		}
		color: colors.tpInfoLabel

		anchors {
			left: btnStartDate.right
			right: btnEndDate.left
			top: btnEndDate.top
			bottom: btnEndDate.bottom
		}
	}
}
